Learn R Programming

tfer (version 1.1)

plot-methods: Methods for Function plot

Description

Methods for function plot

Arguments

Methods

signature(x = "ANY")

plot methods for any R objects.

signature(x = "transfer")

plot method for transfer objects. Allows histograms, barplots of frequencies and probabilities of recovered glass fragments to be plotted. The plot type can be specified as (0 = barplot of probabilities, 1 = barplot of frequencies or 2 = histogram). A barplot of probabilities is set as the default plot.