Learn R Programming

tfer (version 1.1)

tprob-methods: Methods for Function tprob

Description

Methods for function tprob

Arguments

Methods

signature(object = "transfer", x = "missing")

If the second argument is not specified, tprob returns the transfer probabilities for each unique value of simulated recovered glass fragments.

signature(object = "transfer", x = "numeric")

tprob returns the probabilities of recovering the specified x number of glass fragments.